// Interface for SignedKeyList generated by the FE before uploading
export interface SignedKeyList {
    Data: string;
    Signature: string;
}

// Metadata of a public key included in the SKL's Data property
export interface SignedKeyListItem {
    Primary: 0 | 1;
    Flags: number;
    Fingerprint: string;
    SHA256Fingerprints: string[];
}

interface SKLEpochs {
    Data: string | null;
    Signature: string | null;
    MinEpochID: number | null;
    MaxEpochID: number | null;
    ObsolescenceToken?: string;
    ExpectedMinEpochID?: number;
    Revision?: number;
}

export interface ActiveSignedKeyList extends SignedKeyList, SKLEpochs {
    Data: string;
    Signature: string;
}

export interface ObsolescentSignedKeyList extends SKLEpochs {
    ObsolescenceToken: string;
}

export interface ActiveSignedKeyListWithRevision extends ActiveSignedKeyList {
    Revision: number;
}

export interface ObsolescentSignedKeyListWithRevision extends ObsolescentSignedKeyList {
    Revision: number;
}

// SKL served by the server. Note that Data and Signature
// might be missing or be null for obsolescent SKLs
export type FetchedSignedKeyList = ActiveSignedKeyListWithRevision | ObsolescentSignedKeyListWithRevision;
