import { getDateFromVCardProperty, guessDateFromText } from '@proton/shared/lib/contacts/property';
import { VCardDateOrText, VCardProperty } from '@proton/shared/lib/interfaces/contacts/VCard';

describe('property', () => {
    describe('guessDateFromText', () => {
        it('should give expected date when text is a valid date', () => {
            const text = 'Jun 9, 2022';
            const text2 = '2014-02-11T11:30:30';
            const text3 = '2023/12/3';
            const text4 = '03/12/2023';

            expect(guessDateFromText(text)).toEqual(new Date(2022, 5, 9));
            expect(guessDateFromText(text2)).toEqual(new Date(2014, 1, 11, 11, 30, 30));
            expect(guessDateFromText(text3)).toEqual(new Date(2023, 11, 3));
            // Notice in this case, the Date constructor opts for the English format mm/dd instead of dd/mm. This may cause problems during import
            expect(guessDateFromText(text4)).toEqual(new Date(2023, 2, 12));
        });

        it('should give today date when text is not a valid date', () => {
            const text = 'random string to make it fail';

            expect(guessDateFromText(text)).toEqual(undefined);
        });
    });

    describe('getDateFromVCardProperty', () => {
        it('should give the expected date when date is valid', () => {
            const date = new Date(2022, 1, 1);
            const vCardProperty = {
                value: {
                    date,
                },
            } as VCardProperty<VCardDateOrText>;

            expect(getDateFromVCardProperty(vCardProperty)).toEqual(date);
        });

        it('should give today date when date is not valid', () => {
            const date = new Date('random string to make it fail');
            const vCardProperty = {
                value: {
                    date,
                },
            } as VCardProperty<VCardDateOrText>;
            const fallbackDate = new Date();

            expect(getDateFromVCardProperty(vCardProperty, fallbackDate)).toEqual(fallbackDate);
        });

        it('should give expected date when text is a valid date', () => {
            const text = 'Jun 9, 2022';
            const vCardProperty = {
                value: {
                    text,
                },
            } as VCardProperty<VCardDateOrText>;

            expect(getDateFromVCardProperty(vCardProperty)).toEqual(new Date(2022, 5, 9));

            const text2 = '2014-02-11T11:30:30';
            const vCardProperty2 = {
                value: {
                    text: text2,
                },
            } as VCardProperty<VCardDateOrText>;

            expect(getDateFromVCardProperty(vCardProperty2)).toEqual(new Date(2014, 1, 11, 11, 30, 30));
        });

        it('should give today date when text is not a valid date', () => {
            const vCardProperty = {
                value: {
                    text: 'random string to make it fail',
                },
            } as VCardProperty<VCardDateOrText>;
            const fallbackDate = new Date();

            expect(getDateFromVCardProperty(vCardProperty, fallbackDate)).toEqual(fallbackDate);
        });
    });
});
